PdfDocument

Struct PdfDocument 

pub struct PdfDocument {
    pub doc: *mut _HPDF_Doc_Rec,
}
The PDF document.

Fields

doc: *mut _HPDF_Doc_Rec

The reference to the haru document.

Implementations

Source

impl PdfDocument

pub fn new() -> Self

Create an instance of a document object and initialize it.

API: HPDF_New

pub fn set_page_mode(&self, mode: PageMode) -> Result<&Self, HaruError>

set_page_mode() sets how the document should be displayed.

API: HPDF_SetPageMode

pub fn get_page_mode(&self) -> PageMode

get_page_mode() returns the current setting for page mode.

API: HPDF_GetPageMode

pub fn get_font( &self, fontname: &str, encoding_name: Option<&str>, ) -> Result<PdfFont, HaruError>

get_font() returns the font specified by fontname and encoding_name.

API: HPDF_GetFont

pub fn set_page_layout(&self, layout: PageLayout) -> Result<&Self, HaruError>

set_page_layout() sets how the page should be displayed. If this attribute is not set, the setting of the viewer application is used.

API: HPDF_SetPageLayout

pub fn get_page_layout(&self) -> PageLayout

get_page_layout() returns the current setting for page layout.

API: HPDF_GetPageLayout

pub fn save_to_file(&self, filename: &str) -> Result<&Self, HaruError>

save_to_file() saves the PDF document to a file.

pub fn get_error(&self) -> HaruError

Returns the last error code of specified document object.

API: HPDF_GetError

pub fn add_page(&self) -> Result<PdfPage, HaruError>

Create a new page.

API: HPDF_AddPage

pub fn insert_page(&self, page: PdfPage) -> Result<PdfPage, HaruError>

insert_page() creates a new page and inserts it just before the specified page.

API: HPDF_InsertPage

pub fn set_title(&self, title: &str) -> Result<&Self, HaruError>

Set the title of the document.

pub fn set_password( &self, owner_passwd: &str, user_passwd: &str, ) -> Result<&Self, HaruError>

HPDF_SetPassword() sets a password for the document. If the password is set, document contents are encrypted.

pub fn set_compression_mode( &self, mode: CompressionMode, ) -> Result<&Self, HaruError>

HPDF_SetCompressionMode() set the mode of compression.

pub fn set_font_and_size( &self, page: &PdfPage, font: &PdfFont, size: f32, ) -> Result<&Self, HaruError>

set_font_and_size() sets the current font and size.

API: HPDF_Page_SetFontAndSize

pub fn load_tt_font_from_file( &self, filename: &str, embedding: bool, ) -> Result<String, HaruError>

load_tt_font_from_file() loads a TrueType font file and returns a font object.

API: HPDF_LoadTTFontFromFile

pub fn load_tt_font_from_file2( &self, filename: &str, index: u32, embedding: bool, ) -> Result<PdfFont, HaruError>

load_tt_font_from_file2() loads a TrueType font file and returns a font object.

API: HPDF_LoadTTFontFromFile2

pub fn load_type1_font_from_file( &self, afm_filename: &str, pfm_filename: &str, ) -> Result<PdfFont, HaruError>

HPDF_LoadType1FontFromFile() loads a Type1 font file and returns a font object.

API: HPDF_LoadType1FontFromFile

pub fn use_cns_fonts(&self) -> Result<&Self, HaruError>

HPDF_UseCNSFonts() loads Chinese simplified fonts.

API: HPDF_UseCNSFonts

pub fn use_cnt_fonts(&self) -> Result<&Self, HaruError>

HPDF_UseCNTFonts() loads Chinese traditional fonts.

API: HPDF_UseCNTFonts

pub fn use_jp_fonts(&self) -> Result<&Self, HaruError>

HPDF_UseJPFonts() loads Japanese fonts.

API: HPDF_UseJPFonts

pub fn use_utf_encodings(&self) -> Result<&Self, HaruError>

Enable the UTF-8 encoding.

API: HPDF_UseUTFEncodings

pub fn set_current_encoder( &self, encoding_name: &str, ) -> Result<&Self, HaruError>

Set the current encoder.

API: HPDF_SetCurrentEncoder

pub fn use_kr_fonts(&self) -> Result<&Self, HaruError>

HPDF_UseKRFonts() loads Korean fonts.

API: HPDF_UseKRFonts

pub fn load_png_image_from_file( &self, filename: &str, ) -> Result<PdfImage, HaruError>

load_png_image_from_file() loads an external PNG image file.

API: HPDF_LoadPngImageFromFile

pub fn load_png_image_from_file2( &self, filename: &str, ) -> Result<PdfImage, HaruError>

load_png_image_from_file2() loads an external PNG image file. Unlike load_png_image_from_file(), load_png_image_from_file2() does not load all the data immediately (only size and color properties are loaded). The main data are loaded just before the image object is written to PDF, and the loaded data are deleted immediately.

API: HPDF_LoadPngImageFromFile2

pub fn load_jpeg_image_from_file( &self, filename: &str, ) -> Result<PdfImage, HaruError>

HPDF_LoadJpegImageFromFile() loads an external JPEG image file.

API: HPDF_LoadJpegImageFromFile